@@ -48,7 +48,7 @@ void DisplayNumber::setWidth(int digits) {
   QString s(QStringLiteral("0123456789.+-"));
   int width = 0, charWidth=0;
 
-  for (int i = 0; i < 11; i++, width = fm.width(s[i]))
+  for (int i = 0; i < 11; i++, width = fm.boundingRect(s[i]).width())
     charWidth = (width > charWidth) ? width : charWidth;
 
   dg = digits;
